@@ -1,5 +1,8 @@
 package LWP::UserAgent::Patch::LogResponse;
 
+our $DATE = '2015-08-17'; # DATE
+our $VERSION = '0.09'; # VERSION
+
 use 5.010001;
 use strict;
 no warnings;
@@ -7,18 +10,16 @@ no warnings;
 use Module::Patch 0.17 qw();
 use base qw(Module::Patch);
 
-our $VERSION = '0.08'; # VERSION
-
 our %config;
 
 my $p_simple_request = sub {
-    require Log::Any;
+    require Log::Any::IfLOG;
 
     my $ctx  = shift;
     my $orig = $ctx->{orig};
     my $resp = $orig->(@_);
 
-    my $log = Log::Any->get_logger;
+    my $log = Log::Any::IfLOG->get_logger;
     if ($log->is_trace) {
 
         # there is no equivalent of caller_depth in Log::Any, so we do this only
@@ -33,7 +34,7 @@ my $p_simple_request = sub {
         if ($config{-log_response_body}) {
             # XXX or 4, if we're calling request() which calls simple_request()
             my @caller = caller(3);
-            my $log_b = Log::Any->get_logger(
+            my $log_b = Log::Any::IfLOG->get_logger(
                 category => "LWP_Response_Body::".$caller[0]);
             my $content;
             if ($config{-decode_response_body}) {
@@ -71,17 +72,19 @@ sub patch_data {
 1;
 # ABSTRACT: Log raw HTTP responses
 
-
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 LWP::UserAgent::Patch::LogResponse - Log raw HTTP responses
 
 =head1 VERSION
 
-version 0.08
+This document describes version 0.09 of LWP::UserAgent::Patch::LogResponse (from Perl distribution LWP-UserAgent-Patch-LogResponse), released on 2015-08-17.
 
 =head1 SYNOPSIS
 
@@ -139,16 +142,31 @@ WWW::Mechanize, etc).
 Use L<Net::HTTP::Methods::Patch::LogRequest> to log raw HTTP requests being sent
 to servers.
 
+=head1 HOMEPAGE
+
+Please visit the project's homepage at L<https://metacpan.org/release/LWP-UserAgent-Patch-LogResponse>.
+
+=head1 SOURCE
+
+Source repository is at L<https://github.com/sharyanto/perl-LWP-UserAgent-patch-log_response>.
+
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=LWP-UserAgent-Patch-LogResponse>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
 =head1 AUTHOR
 
-Steven Haryanto <stevenharyanto@gmail.com>
+perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Steven Haryanto.
+This software is copyright (c) 2015 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
